@@ -1,5 +1,5 @@
 from keap import Keap
-from keap.exceptions import KeapUnauthorizedException, KeapException, KeapTokenExpiredException
+from keap.exceptions import KeapXMLRPCException
 
 try:
     from xmlrpclib import ServerProxy, Error
@@ -40,12 +40,27 @@ class BaseService:
         try:
             return call(self.keap.token.access_token, *args)
         except self.client.error as e:
-            error_code = e.errcode
-            error_message = e.errmsg
-            headers = e.headers
-            if error_code == 401:  # Unauthorized
-                raise KeapUnauthorizedException(error_message)
-            raise KeapException(error_message)
+            if type(e) == Fault:
+                raise KeapXMLRPCException(None, e.faultCode, e.faultString, None)
+            else:
+                e_dict = e.__dict__
+                if 'url' in e_dict:
+                    url = e_dict['url']
+                else:
+                    url = None
+                if 'errcode' in e_dict:
+                    errcode = e_dict['errcode']
+                else:
+                    errcode = None
+                if 'errmsg' in e_dict:
+                    errmsg = e_dict['errmsg']
+                else:
+                    errmsg = None
+                if 'headers' in e_dict:
+                    headers = e_dict['headers']
+                else:
+                    headers = []
+                raise KeapXMLRPCException(url, errcode, errmsg, headers)
 
     def server(self):
         return self.client
